"use client"

import { useState, useEffect } from "react"
import { useRouter } from "next/navigation"
import Link from "next/link"
import { ArrowLeft, ArrowRight, Clock, CheckCircle, XCircle, AlertCircle, Info } from "lucide-react"
import NavBar from "@/components/nav-bar"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardFooter, CardHeader, CardTitle } from "@/components/ui/card"
import { Alert, AlertDescription } from "@/components/ui/alert"
import { Progress } from "@/components/ui/progress"
import { RadioGroup, RadioGroupItem } from "@/components/ui/radio-group"
import { Label } from "@/components/ui/label"
import { getSimulationById } from "@/data/simulations"

export default function SimulationPage({ params }: { params: { level: string; id: string } }) {
  const router = useRouter()
  const simulationId = params.id
  const levelId = params.level

  const [currentQuestionIndex, setCurrentQuestionIndex] = useState(0)
  const [answers, setAnswers] = useState<Record<string, string>>({})
  const [showExplanation, setShowExplanation] = useState(false)
  const [timeLeft, setTimeLeft] = useState(0) // en secondes
  const [isFinished, setIsFinished] = useState(false)

  const simulationData = getSimulationById(simulationId)

  const { simulation, level } = simulationData || { simulation: { duration: 0, questions: [] }, level: "" }

  const currentQuestion = simulation.questions[currentQuestionIndex]
  const totalQuestions = simulation.questions.length
  const progress = (currentQuestionIndex / totalQuestions) * 100

  useEffect(() => {
    if (simulationData) {
      setTimeLeft(simulation.duration * 60) // en secondes
    }
  }, [simulationData])

  useEffect(() => {
    if (isFinished) return

    const timer = setInterval(() => {
      setTimeLeft((prev) => {
        if (prev <= 1) {
          clearInterval(timer)
          setIsFinished(true)
          return 0
        }
        return prev - 1
      })
    }, 1000)

    return () => clearInterval(timer)
  }, [isFinished])

  const formatTime = (seconds: number) => {
    const minutes = Math.floor(seconds / 60)
    const remainingSeconds = seconds % 60
    return `${minutes}:${remainingSeconds < 10 ? "0" : ""}${remainingSeconds}`
  }

  const handleAnswer = (value: string) => {
    setAnswers((prev) => ({
      ...prev,
      [currentQuestion.id]: value,
    }))
  }

  const goToNextQuestion = () => {
    if (currentQuestionIndex < totalQuestions - 1) {
      setCurrentQuestionIndex((prev) => prev + 1)
      setShowExplanation(false)
    } else {
      setIsFinished(true)
    }
  }

  const goToPreviousQuestion = () => {
    if (currentQuestionIndex > 0) {
      setCurrentQuestionIndex((prev) => prev - 1)
      setShowExplanation(false)
    }
  }

  const calculateScore = () => {
    let correctAnswers = 0
    simulation.questions.forEach((question) => {
      if (answers[question.id] === question.correctAnswer) {
        correctAnswers++
      }
    })
    return {
      score: correctAnswers,
      total: totalQuestions,
      percentage: Math.round((correctAnswers / totalQuestions) * 100),
    }
  }

  if (!simulationData) {
    return (
      <div className="min-h-screen bg-gray-50 flex items-center justify-center">
        <div className="text-center">
          <h1 className="text-2xl font-bold mb-4">Simulation non trouvée</h1>
          <Link href={`/simulations/${levelId}`} passHref>
            <Button>Retour aux simulations</Button>
          </Link>
        </div>
      </div>
    )
  }

  if (isFinished) {
    const result = calculateScore()
    const isPassed = result.percentage >= 70 // 70% pour réussir

    return (
      <div className="min-h-screen bg-gray-50">
 

        <div className="container mx-auto px-4 py-12">
          <div className="max-w-3xl mx-auto">
            <Card className="border-2 shadow-lg">
              <CardHeader className={`text-white ${isPassed ? "bg-green-600" : "bg-red-600"}`}>
                <CardTitle className="text-center text-2xl">
                  {isPassed ? (
                    <div className="flex items-center justify-center">
                      <CheckCircle className="mr-2 h-6 w-6" />
                      Félicitations !
                    </div>
                  ) : (
                    <div className="flex items-center justify-center">
                      <XCircle className="mr-2 h-6 w-6" />
                      Essayez encore !
                    </div>
                  )}
                </CardTitle>
              </CardHeader>
              <CardContent className="pt-6">
                <div className="text-center mb-6">
                  <h2 className="text-xl font-semibold mb-2">Résultat de votre simulation</h2>
                  <p className="text-gray-600 mb-4">{simulation.title}</p>

                  <div className="flex justify-center mb-6">
                    <div className="w-32 h-32 rounded-full border-8 border-gray-200 flex items-center justify-center">
                      <div className={`text-3xl font-bold ${isPassed ? "text-green-600" : "text-red-600"}`}>
                        {result.percentage}%
                      </div>
                    </div>
                  </div>

                  <div className="grid grid-cols-2 gap-4 max-w-md mx-auto mb-6">
                    <div className="bg-gray-100 p-4 rounded-lg">
                      <p className="text-sm text-gray-600">Bonnes réponses</p>
                      <p className="text-xl font-semibold text-green-600">
                        {result.score} / {result.total}
                      </p>
                    </div>
                    <div className="bg-gray-100 p-4 rounded-lg">
                      <p className="text-sm text-gray-600">Temps utilisé</p>
                      <p className="text-xl font-semibold">{formatTime(simulation.duration * 60 - timeLeft)}</p>
                    </div>
                  </div>

                  <p className="mb-4">
                    {isPassed
                      ? "Vous avez réussi cette simulation ! Continuez à vous entraîner pour améliorer vos connaissances."
                      : "Vous n'avez pas atteint le score minimum requis (70%). Révisez et réessayez !"}
                  </p>
                </div>
              </CardContent>
              <CardFooter className="flex justify-between">
                <Link href={`/simulations/${levelId}`} passHref>
                  <Button variant="outline">
                    <ArrowLeft className="mr-2 h-4 w-4" />
                    Retour aux simulations
                  </Button>
                </Link>
                <Link href={`/simulations/${levelId}/${simulationId}`} passHref>
                  <Button>
                    Recommencer
                    <ArrowRight className="ml-2 h-4 w-4" />
                  </Button>
                </Link>
              </CardFooter>
            </Card>

            <div className="mt-8">
              <h3 className="text-xl font-semibold mb-4">Révision des questions</h3>
              <div className="space-y-6">
                {simulation.questions.map((question, index) => (
                  <Card key={question.id} className="border">
                    <CardHeader className="pb-2">
                      <div className="flex items-start justify-between">
                        <CardTitle className="text-lg">Question {index + 1}</CardTitle>
                        {answers[question.id] === question.correctAnswer ? (
                          <CheckCircle className="h-5 w-5 text-green-600" />
                        ) : (
                          <XCircle className="h-5 w-5 text-red-600" />
                        )}
                      </div>
                    </CardHeader>
                    <CardContent>
                      <p className="mb-4">{question.question}</p>
                      <div className="space-y-2">
                        {question.options.map((option) => (
                          <div
                            key={option}
                            className={`p-3 rounded-md ${
                              option === question.correctAnswer
                                ? "bg-green-100 border border-green-300"
                                : answers[question.id] === option && option !== question.correctAnswer
                                  ? "bg-red-100 border border-red-300"
                                  : "bg-gray-100 border border-gray-200"
                            }`}
                          >
                            {option}
                          </div>
                        ))}
                      </div>
                      <div className="mt-4 p-3 bg-blue-50 border border-blue-200 rounded-md">
                        <p className="text-sm font-medium text-blue-800">Explication:</p>
                        <p className="text-sm text-blue-700">{question.explanation}</p>
                      </div>
                    </CardContent>
                  </Card>
                ))}
              </div>
            </div>
          </div>
        </div>
      </div>
    )
  }

  return (
    <div className="min-h-screen bg-gray-50">
      <NavBar />

      <div className="container mx-auto px-4 py-8">
        <div className="max-w-3xl mx-auto">
          {/* En-tête */}
          <div className="mb-6 flex justify-between items-center">
            <div>
              <Link
                href={`/simulations/${levelId}`}
                className="inline-flex items-center text-gray-600 hover:text-gray-900"
              >
                <ArrowLeft className="mr-2 h-4 w-4" />
                Quitter la simulation
              </Link>
            </div>
            <div className="flex items-center">
              <Clock className="h-5 w-5 text-gray-600 mr-2" />
              <span className={`font-medium ${timeLeft < 60 ? "text-red-600" : "text-gray-700"}`}>
                {formatTime(timeLeft)}
              </span>
            </div>
          </div>

          {/* Progression */}
          <div className="mb-6">
            <div className="flex justify-between items-center mb-2">
              <span className="text-sm text-gray-600">
                Question {currentQuestionIndex + 1} sur {totalQuestions}
              </span>
              <span className="text-sm font-medium">{Math.round(progress)}%</span>
            </div>
            <Progress value={progress} className="h-2" />
          </div>

          {/* Question */}
          <Card className="border-2 shadow-md mb-6">
            <CardHeader>
              <CardTitle className="text-xl">{currentQuestion.question}</CardTitle>
            </CardHeader>
            <CardContent>
              <RadioGroup value={answers[currentQuestion.id] || ""} onValueChange={handleAnswer} className="space-y-3">
                {currentQuestion.options.map((option) => (
                  <div key={option} className="flex items-center space-x-2 border p-3 rounded-md hover:bg-gray-50">
                    <RadioGroupItem value={option} id={option} />
                    <Label htmlFor={option} className="flex-grow cursor-pointer">
                      {option}
                    </Label>
                  </div>
                ))}
              </RadioGroup>

              {showExplanation && (
                <div className="mt-6 p-4 bg-blue-50 border border-blue-200 rounded-md">
                  <div className="flex items-start">
                    <Info className="h-5 w-5 text-blue-600 mr-2 mt-0.5" />
                    <div>
                      <h4 className="font-medium text-blue-800 mb-1">Explication</h4>
                      <p className="text-blue-700">{currentQuestion.explanation}</p>
                    </div>
                  </div>
                </div>
              )}
            </CardContent>
            <CardFooter className="flex justify-between">
              <Button variant="outline" onClick={goToPreviousQuestion} disabled={currentQuestionIndex === 0}>
                <ArrowLeft className="mr-2 h-4 w-4" />
                Précédent
              </Button>

              <div className="flex space-x-2">
                <Button
                  variant="outline"
                  onClick={() => setShowExplanation(!showExplanation)}
                  disabled={!answers[currentQuestion.id]}
                >
                  {showExplanation ? "Masquer l'explication" : "Voir l'explication"}
                </Button>

                <Button onClick={goToNextQuestion} disabled={!answers[currentQuestion.id]}>
                  {currentQuestionIndex === totalQuestions - 1 ? "Terminer" : "Suivant"}
                  <ArrowRight className="ml-2 h-4 w-4" />
                </Button>
              </div>
            </CardFooter>
          </Card>

          {/* Alerte */}
          {!answers[currentQuestion.id] && (
            <Alert className="border-amber-300 bg-amber-50">
              <AlertCircle className="h-5 w-5 text-amber-600" />
              <AlertDescription className="ml-2 text-amber-700">
                Veuillez sélectionner une réponse pour continuer.
              </AlertDescription>
            </Alert>
          )}
        </div>
      </div>
    </div>
  )
}
